=================================
Essential Components (Docstrings)
=================================

CoordinateSym
=============

.. autoclass:: sympy.physics.mechanics.essential.CoordinateSym


ReferenceFrame
==============

.. autoclass:: sympy.physics.mechanics.essential.ReferenceFrame
   :members:


Vector
======

.. autoclass:: sympy.physics.mechanics.essential.Vector
   :members:


Dyadic
======

.. autoclass:: sympy.physics.mechanics.essential.Dyadic
   :members:
